[coreboot-gerrit] New patch to review for coreboot: vendorcode/google/chromeos/vboot2: use cbmem for postcar region selection

Aaron Durbin (adurbin@chromium.org) gerrit at coreboot.org
Tue May 24 21:52:52 CEST 2016


Aaron Durbin (adurbin at chromium.org) just uploaded a new patch set to gerrit, which you can find at https://review.coreboot.org/14959

-gerrit

commit adf071427f993ee36b59aa17e9e8ed7a95bc2eb8
Author: Aaron Durbin <adurbin at chromium.org>
Date:   Tue May 24 14:50:45 2016 -0500

    vendorcode/google/chromeos/vboot2: use cbmem for postcar region selection
    
    When the vboot cbfs selection runs in postcar stage it should be
    utilizing cbmem to locate the vboot selected region.
    
    Change-Id: I027ba19438468bd690d74ae55007393f051fde42
    Signed-off-by: Aaron Durbin <adurbin at chromium.org>
---
 src/vendorcode/google/chromeos/vboot2/common.c | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/src/vendorcode/google/chromeos/vboot2/common.c b/src/vendorcode/google/chromeos/vboot2/common.c
index 4282408..749f328 100644
--- a/src/vendorcode/google/chromeos/vboot2/common.c
+++ b/src/vendorcode/google/chromeos/vboot2/common.c
@@ -65,8 +65,8 @@ static struct selected_region *vb2_selected_region(void)
 {
 	struct selected_region *sel_reg = NULL;
 
-	/* Ramstage always uses cbmem as a source of truth. */
-	if (ENV_RAMSTAGE)
+	/* Ramstage and postcar always uses cbmem as a source of truth. */
+	if (ENV_RAMSTAGE || ENV_POSTCAR)
 		sel_reg = cbmem_find(CBMEM_ID_VBOOT_SEL_REG);
 	else if (ENV_ROMSTAGE) {
 		/* Try cbmem first. Fall back on working data if not found. */



More information about the coreboot-gerrit mailing list